@@ -1,3 +1,3 @@
 from .XNode2Vec import similar_nodes, cluster_generation, clusters_detection, low_limit_network
-from .XNode2Vec import load_model, draw_community
+from .XNode2Vec import load_model, draw_community, nx_to_Graph
 from .XNode2Vec import generate_edgelist, edgelist_from_csv, complete_edgelist, stellar_edgelist, best_line_projection, recover_points
